# Acknowledgment of Image Source

## CZI file "xt-scan-lsm980.czi"
The CZI file "xt-scan-lsm980.czi" provided in this folder is taken from the public Zenodo repository <https://zenodo.org/records/8305531> under the Creative Commons Attribution 4.0 International (CC BY 4.0) license. Please cite the original source if you use this file in your work:

Nicolas Chiaruttini. (2023). CZI file examples [Data set]. Zenodo. https://doi.org/10.5281/zenodo.8305531

We use this file solely for testing and demonstration purposes within the OMIO project.  We did not modify the file in any way.

## LSM file "032113-18.lsm"
The LSM file "032113-18.lsm" provided in this folder is taken from the public Zenodo repository <https://zenodo.org/records/4980354> under the Creative Commons Zero v1.0 Universal (CC0 1.0) license. Please cite the original source if you use this file in your work:

Jermusyk, A., Murphy, N. P., & Reeves, G. (2017). Data from: Analyzing negative feedback using a synthetic gene network expressed in the Drosophila melanogaster embryo [Data set]. Zenodo. https://doi.org/10.5061/dryad.68864

We use this file solely for testing and demonstration purposes within the OMIO project. We did not modify the file in any way.
